"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var registry_1 = require("./registry");
var express = require("express");
var chai_1 = require("chai");
var js_restful_1 = require("js-restful");
var winston = require("winston");
var test_util_spec_1 = require("./test-util.spec");
var TestServiceC = (function () {
    function TestServiceC() {
    }
    return TestServiceC;
}());
var TestServcieRequireSecurityContext = (function () {
    function TestServcieRequireSecurityContext() {
    }
    TestServcieRequireSecurityContext = __decorate([
        js_restful_1.PermitAll()
    ], TestServcieRequireSecurityContext);
    return TestServcieRequireSecurityContext;
}());
describe('service-registry', function () {
    var app;
    beforeEach(function () {
        app = express();
    });
    it('should be possible to register an object', function () {
        var fn = function () {
            new registry_1.JsRestfulRegistry(app).registerService(new TestServiceC());
        };
        chai_1.expect(fn).to.not.throw(Error);
    });
    it('should only be possible to register an object of a specific type once', function () {
        var registry = new registry_1.JsRestfulRegistry(app);
        registry.registerService(new TestServiceC());
        var fn = function () {
            registry.registerService(new TestServiceC());
        };
        chai_1.expect(fn).to.throw(Error);
    });
    it('should only not be possible to register a type', function () {
        var fn = function () {
            new registry_1.JsRestfulRegistry(app).registerService(TestServiceC);
        };
        chai_1.expect(fn).to.throw(TypeError);
    });
    it('should not be possible to register a service that needs a security context when there is no security context available', function () {
        var fn = function () {
            new registry_1.JsRestfulRegistry(app).registerService(new TestServcieRequireSecurityContext());
        };
        chai_1.expect(fn).to.throw(Error);
    });
    it('should be possible to register a service with sec context if a factory is registered', function () {
        var fn = function () {
            var registry = new registry_1.JsRestfulRegistry(app);
            registry.registerSecurityContextFactory(new test_util_spec_1.Factory());
            registry.registerService(new TestServcieRequireSecurityContext());
        };
        chai_1.expect(fn).to.not.throw(Error);
    });
    it('should be possible to set a custom logger', function () {
        var SpyLogger = (function (_super) {
            __extends(SpyLogger, _super);
            function SpyLogger() {
                var _this = _super !== null && _super.apply(this, arguments) || this;
                _this.called = false;
                _this.log = function () {
                    _this.called = true;
                    return _this;
                };
                return _this;
            }
            return SpyLogger;
        }(winston.Logger));
        var logger = new SpyLogger();
        var registry = new registry_1.JsRestfulRegistry(app, { logger: logger });
        registry.registerService(new TestServiceC());
        chai_1.expect(logger.called).to.be.true;
    });
});
//# sourceMappingURL=registry.spec.js.map