"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var namings = require("./namings");
var js_restful_1 = require("js-restful");
var RenderWithRenderer = (function () {
    function RenderWithRenderer(viewName) {
        this.viewName = viewName;
    }
    RenderWithRenderer.prototype.render = function (res, value) {
        res.render(this.viewName, value);
    };
    return RenderWithRenderer;
}());
exports.RenderWithRenderer = RenderWithRenderer;
var DefaultRenderer = (function () {
    function DefaultRenderer(method) {
        this.method = method;
    }
    ;
    DefaultRenderer.prototype.render = function (res, value) {
        if (typeof value === 'undefined' || value === null) {
            if (this.isResponseParameterPresent()) {
                // do not send any reponse values if a HttpReponse Context param is provided to the service method.
                return;
            }
            this.setToPlainText(res);
            res.send('');
        }
        else if (typeof value === 'boolean' || typeof value === 'number' || typeof value === 'string') {
            this.setToPlainText(res);
            res.send('' + value);
        }
        else {
            res.json(value);
        }
    };
    DefaultRenderer.prototype.isResponseParameterPresent = function () {
        var result = false;
        this.method.contextParams.forEach(function (contextParam) {
            if (js_restful_1.ContextTypes[contextParam.paramName] == js_restful_1.ContextTypes.HttpResponse) {
                result = true;
            }
        });
        return result;
    };
    DefaultRenderer.prototype.setToPlainText = function (res) {
        res.header("Content-Type", "text/plain");
    };
    return DefaultRenderer;
}());
exports.DefaultRenderer = DefaultRenderer;
var RendererFactory = (function () {
    function RendererFactory() {
    }
    RendererFactory.getRenderer = function (service, method) {
        if (Reflect.hasMetadata(namings.renderWith, service[method.methodName])) {
            // return a Renderer that support RenderWith
            var viewName = Reflect.getMetadata(namings.renderWith, service[method.methodName]);
            return new RenderWithRenderer(viewName);
        }
        // Return the default renderer.
        return new DefaultRenderer(method);
    };
    return RendererFactory;
}());
exports.RendererFactory = RendererFactory;
//# sourceMappingURL=renderers.js.map